@@ -122,7 +122,7 @@ class CK_OBJECT_HANDLE(PyKCS11.LowLevel.CK_OBJECT_HANDLE):
 
         dico = dict()
         for key, attr in zip(all_attributes, attributes):
-            if attr == None:
+            if attr is None:
                 continue
             if key == CKA_CLASS:
                 dico[PyKCS11.CKA[key]] = PyKCS11.CKO[attr]
@@ -442,9 +442,9 @@ class PyKCS11Lib(object):
         @return: a L{PyKCS11Lib} object
         @raise PyKCS11Error(-1): when the load fails
         """
-        if pkcs11dll_filename == None:
+        if pkcs11dll_filename is None:
             pkcs11dll_filename = os.getenv("PYKCS11LIB")
-            if pkcs11dll_filename == None:
+            if pkcs11dll_filename is None:
                 raise PyKCS11Error(-1, "No PKCS11 library specified (set PYKCS11LIB env variable)")
         rv = self.lib.Load(pkcs11dll_filename, True)
         if rv == 0:
@@ -589,11 +589,7 @@ class PyKCS11Lib(object):
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
-        s = Session()
-        s.lib = self.lib
-        s.slot = slot
-        s.session = se
-        return s
+        return Session(self, slot, se)
 
     def getMechanismList(self, slot):
         """
@@ -678,11 +674,38 @@ class Mechanism(object):
 MechanismSHA1 = Mechanism(CKM_SHA_1, None)
 MechanismRSAPKCS1 = Mechanism(CKM_RSA_PKCS, None)
 MechanismRSAGENERATEKEYPAIR = Mechanism(CKM_RSA_PKCS_KEY_PAIR_GEN, None)
+MechanismAESGENERATEKEY = Mechanism(CKM_AES_KEY_GEN, None)
 
 
 class Session(object):
     """ Manage L{PyKCS11Lib.openSession} objects """
 
+    def __init__(self, pykcs11, slot, session):
+        """
+        @param pykcs11: PyKCS11 library object
+        @type pykcs11: PyKCS11Lib
+        @param slot: slot number
+        @type slot: integer
+        @param session: session handle
+        @type session: instance of CK_SESSION_HANDLE
+        """
+        if not isinstance(pykcs11, PyKCS11Lib):
+            raise TypeError("pykcs11 must be a PyKCS11Lib")
+        if not isinstance(session, LowLevel.CK_SESSION_HANDLE):
+            raise TypeError("session must be a CK_SESSION_HANDLE")
+
+        # hold the PyKCS11Lib reference, so that it's not Garbage Collection'd
+        self.pykcs11 = pykcs11
+        self.slot = slot
+        self.session = session
+
+    @property
+    def lib(self):
+        """
+        Get the low level lib of the owning PyKCS11Lib
+        """
+        return self.pykcs11.lib
+
     def closeSession(self):
         """
         C_CloseSession
@@ -822,11 +845,11 @@ class Session(object):
         rv = self.lib.C_DigestInit(self.session, m)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #first call get digest size
+        # first call get digest size
         rv = self.lib.C_Digest(self.session, data1, digest)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #second call get actual digest data
+        # second call get actual digest data
         rv = self.lib.C_Digest(self.session, data1, digest)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -871,11 +894,11 @@ class Session(object):
         rv = self.lib.C_SignInit(self.session, m, key)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #first call get signature size
+        # first call get signature size
         rv = self.lib.C_Sign(self.session, data1, signature)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #second call get actual signature data
+        # second call get actual signature data
         rv = self.lib.C_Sign(self.session, data1, signature)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -964,11 +987,11 @@ class Session(object):
         rv = self.lib.C_EncryptInit(self.session, m, key)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #first call get encrypted size
+        # first call get encrypted size
         rv = self.lib.C_Encrypt(self.session, data1, encrypted)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #second call get actual encrypted data
+        # second call get actual encrypted data
         rv = self.lib.C_Encrypt(self.session, data1, encrypted)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -1013,11 +1036,11 @@ class Session(object):
         rv = self.lib.C_DecryptInit(self.session, m, key)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #first call get decrypted size
+        # first call get decrypted size
         rv = self.lib.C_Decrypt(self.session, data1, decrypted)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #second call get actual decrypted data
+        # second call get actual decrypted data
         rv = self.lib.C_Decrypt(self.session, data1, decrypted)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -1051,11 +1074,11 @@ class Session(object):
             ps = to_param_string(mecha.param)
             m.pParameter = ps
             m.ulParameterLen = len(mecha.param)
-        #first call get wrapped size
+        # first call get wrapped size
         rv = self.lib.C_WrapKey(self.session, m, wrappingKey, key, wrapped)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
-        #second call get actual wrapped key data
+        # second call get actual wrapped key data
         rv = self.lib.C_WrapKey(self.session, m, wrappingKey, key, wrapped)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -1157,7 +1180,8 @@ class Session(object):
             CKA_UNWRAP,
             CKA_VERIFY,
             CKA_VERIFY_RECOVER,
-            CKA_WRAP):
+            CKA_WRAP,
+            CKA_WRAP_WITH_TRUSTED):
             return True
         return False
 
@@ -1195,6 +1219,30 @@ class Session(object):
                 raise PyKCS11Error(-2)
         return t
 
+    def generateKey(self, template, mecha=MechanismAESGENERATEKEY):
+        """
+        generate a secret key
+
+        @param template: template for the secret key
+        @param mecha: mechanism to use
+        @return: handle of the generated key
+        @rtype: PyKCS11.LowLevel.CK_OBJECT_HANDLE
+        """
+        t = self._template2ckattrlist(template)
+        ck_handle = PyKCS11.LowLevel.CK_OBJECT_HANDLE()
+        m = PyKCS11.LowLevel.CK_MECHANISM()
+        ps = None  # must be declared here or may be deallocated too early
+        m.mechanism = mecha.mechanism
+        if (mecha.param):
+            # Convert the parameter to a string representation so SWIG gets a char*
+            ps = to_param_string(mecha.param)
+            m.pParameter = ps
+            m.ulParameterLen = len(mecha.param)
+        rv = self.lib.C_GenerateKey(self.session, m, t, ck_handle)
+        if rv != CKR_OK:
+            raise PyKCS11Error(rv)
+        return ck_handle
+
     def generateKeyPair(self, templatePub, templatePriv, mecha=MechanismRSAGENERATEKEYPAIR):
         """
         generate a key pair
@@ -1210,7 +1258,7 @@ class Session(object):
         ck_pub_handle = PyKCS11.LowLevel.CK_OBJECT_HANDLE()
         ck_prv_handle = PyKCS11.LowLevel.CK_OBJECT_HANDLE()
         m = PyKCS11.LowLevel.CK_MECHANISM()
-        ps = None # must be declared here or may be deallocated too early
+        ps = None  # must be declared here or may be deallocated too early
         m.mechanism = mecha.mechanism
         if (mecha.param):
             # Convert the parameter to a string representation so SWIG gets a char*
