@@ -30,7 +30,7 @@ tokenInfo = PyKCS11.LowLevel.CK_TOKEN_INFO()
 slotList = PyKCS11.LowLevel.ckintlist()
 pin = "12345678"
 
-print("Load of " + lib + ": " + str(a.Load(lib, 1)))
+print("Load of " + lib + ": " + str(a.Load(lib, True)))
 print("C_GetInfo: " + hex(a.C_GetInfo(info)))
 print("Library manufacturerID: " + info.GetManufacturerID())
 del info
@@ -57,8 +57,8 @@ for x in range(len(slotList)):
 print("C_OpenSession(): " + hex(a.C_OpenSession(slotList[0], PyKCS11.LowLevel.CKF_SERIAL_SESSION, session)))
 print("C_Login(): " + hex(a.C_Login(session, PyKCS11.LowLevel.CKU_USER, pin)))
 
-SearchResult = PyKCS11.ckobjlist(10)
-SearchTemplate = PyKCS11.ckattrlist(2)
+SearchResult = PyKCS11.LowLevel.ckobjlist(10)
+SearchTemplate = PyKCS11.LowLevel.ckattrlist(2)
 SearchTemplate[0].SetNum(PyKCS11.LowLevel.CKA_CLASS, PyKCS11.LowLevel.CKO_CERTIFICATE)
 SearchTemplate[1].SetBool(PyKCS11.LowLevel.CKA_TOKEN, True)
 
@@ -68,7 +68,7 @@ print("C_FindObjectsFinal: " + hex(a.C_FindObjectsFinal(session)))
 
 for x in SearchResult:
     print("object: " + hex(x.value()))
-    valTemplate = PyKCS11.ckattrlist(2)
+    valTemplate = PyKCS11.LowLevel.ckattrlist(2)
     valTemplate[0].SetType(PyKCS11.LowLevel.CKA_LABEL)
     # valTemplate[0].Reserve(128)
     valTemplate[1].SetType(PyKCS11.LowLevel.CKA_CLASS)
