@@ -1,5 +1,5 @@
 //   Copyright (C) 2004 Midori (midori -- a-t -- paipai dot net)
-//   Copyright (C) 2008 Ludovic Rousseau <ludovic.rousseau@free.fr>
+//   Copyright (C) 2008-2014 Ludovic Rousseau <ludovic.rousseau@free.fr>
 //
 // This file is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 
 #include "stdafx.h"
 #include "pykcs11string.h"
@@ -202,6 +202,10 @@ CK_RV CPKCS11Lib::C_SetPIN(
 	CK_ULONG ulNewLen)
 {
 	CPKCS11LIB_PROLOGUE(C_SetPIN);
+	if (NULL == pOldPin)
+		ulOldLen = 0;
+	if (NULL == pNewPin)
+		ulNewLen = 0;
 	rv = m_pFunc->C_SetPIN(hSession,
 		(CK_UTF8CHAR_PTR)pOldPin, ulOldLen,
 		(CK_UTF8CHAR_PTR)pNewPin, ulNewLen);
@@ -255,6 +259,8 @@ CK_RV CPKCS11Lib::C_Login(
 	CK_ULONG ulPinLen)
 {
 	CPKCS11LIB_PROLOGUE(C_Login);
+	if (NULL == pPin)
+		ulPinLen = 0;
 	rv = m_pFunc->C_Login(hSession, userType, (CK_UTF8CHAR_PTR)pPin, ulPinLen);
 	CPKCS11LIB_EPILOGUE;
 	return rv;
